@@ -23,6 +23,9 @@ class DBConnect:
 
         if not self.mongo_home or not self.mongo_port:
             logging.error('MongoDB(组件)的组件连接信息是不完整的')
+        else:
+            logging.warning('已连接地址为 {0}:{1} 的 MongoDB(组件)'.format(
+                self.mongo_home, self.mongo_port))
 
         self.mongo_client = pymongo.MongoClient(
             host=self.mongo_home,
