@@ -89,7 +89,7 @@ class VerifyToken:
             return {'token_id': '0f0f0f0f0f0f0f0f0f0f0f0f', 'user_name': 'tmp_use', 'real_name': '调试账号'}
         if not self.redis_connect:
             handle_abnormal(
-                message='计算组件未建立连接/依赖到认证中心，无法验证凭证',
+                message='计算组件未建立连接/依赖到认证中心(Redis)，无法验证凭证',
                 status=500,
             )
         token = request.headers.get('token')  # 获取请求头中的Token
@@ -146,11 +146,11 @@ class VerifyToken:
                                 self.permission_set_db.write_one_docu(
                                     docu=find_dict)
                     else:
-                        logging.error('计算组件未建立连接/依赖到认证中心，无法注册对应的角色')
+                        logging.error('计算组件未建立连接/依赖到认证中心(MongoDB)，无法注册对应的角色权限')
             except Exception as e:
                 logging.warning('添加权限中心/名称失败', str(e))
         else:
-            logging.error('计算组件未建立连接/依赖到认证中心，无法注册权限')
+            logging.error('计算组件未读取到认证中心(MongoDB)连接依赖变量，无法注册权限')
 
     def permission_verify(self, center_name, permission_name) -> dict:
         """
@@ -163,18 +163,18 @@ class VerifyToken:
             return {'permission_list': self.debug_permission, 'is_all_data': True}
         if not self.redis_connect:
             handle_abnormal(
-                message='计算组件未建立连接/依赖到认证中心-Redis服务，无法验证权限',
+                message='计算组件未建立连接/依赖到认证中心(Redis)服务，无法验证权限',
                 status=500,
             )
         elif not self.role_db:
             handle_abnormal(
-                message='计算组件未建立连接/依赖到认证中心-角色集合({0})，无法验证权限'.format(
+                message='计算组件未建立连接/依赖到认证中心(MongoDB)-角色集合({0})，无法验证权限'.format(
                     self.mongo_role),
                 status=500,
             )
         elif not self.user_db:
             handle_abnormal(
-                message='计算组件未建立连接/依赖到认证中心-用户集合({0})，无法验证权限'.format(
+                message='计算组件未建立连接/依赖到认证中心(MongoDB)-用户集合({0})，无法验证权限'.format(
                     self.mongo_user),
                 status=500,
             )
